/*
 * Copyright (c) 2002-2015 Oracle and/or its affiliates. All rights reserved.
 */

package javasoft.sqe.tests.javax.mail.internet.MimePartDataSource;

import java.util.*;
import java.io.*;
import javax.mail.*;
import javax.mail.internet.*;
import com.sun.javatest.*;
import javasoft.sqe.tests.javax.mail.util.MailTest;

/**
 * This class tests the <strong>MimePartDataSource()</strong> API.
 * It does by passing various valid input values and then checking
 * the type of the returned object.	<p>
 *
 *		Constructor, that constructs a DataSource from a MimePart. <p>
 * api2test: public MimePartDataSource(MimePart)  <p>
 *
 * how2test: Call constructor with mimepart argument, verify the type of object created
 *	     to be of MimePartDataSource. If so then testcase passes, otherwise it fails.
 */

public class mimePartDataSource_Test extends MailTest {

    public static void main( String argv[] )
    {
        mimePartDataSource_Test test = new mimePartDataSource_Test();
        Status s = test.run(argv, System.err, System.out);
	s.exit();
    }

    public Status run(String argv[], PrintWriter log, PrintWriter out)
    {
	super.run(argv, log, out);
	parseArgs(argv);	// parse command-line options

        out.println("\nTesting class MimePartDataSource: MimePartDataSource(MimePart)\n");

        try {
          // Connect to host server
             Store store = connect2host(protocol, host, user, password);

          // Get a Folder object
	     Folder root = getRootFolder(store);
             Folder folder = root.getFolder(mailbox);

             if( folder == null ) {
                 return Status.failed("Invalid folder object!");
             }
             folder.open(Folder.READ_ONLY);

             if( msgcount == -1 ) {
                 msgcount = folder.getMessageCount();
                 if( msgcount < 1 )
                     return Status.failed("Mail folder is empty!");
             }
          // Get message object
             MimeMessage msg = (MimeMessage)folder.getMessage(1);

             if( msg == null ) {
                 return Status.failed("Warning: Failed to get message number: 1");
             }
	  // BEGIN UNIT TEST 1:
	     out.println("UNIT TEST 1:  MimePartDataSource((MimePart)msg)");

	  // Create a MimePartDataSource object
	     MimePartDataSource mpds = new MimePartDataSource((MimePart)msg); // API TEST

	     if( mpds != null )
		 out.println("UNIT TEST 1: passed\n");
	     else {
		   out.println("UNIT TEST 1: FAILED\n");
		   errors++;
	     }
	  // END UNIT TEST 1:
	     folder.close(false);
             store.close();
             checkStatus();

        } catch ( Exception e ) {
	     handlException(e);
        }
	return status;
     }
}
